pydot3
======

## Python 2 and Python 3 compatible interface to Graphviz's Dot.

Includes fixes from https://github.com/erocarrera/pydot, which is not compatible with Python 3.x for some reasons.

Originally author by Michael Krause <michael@krause-software.de> with fixes from Ero Carrera <ero@dkbza.org>. I only fixed the places incompatible with Python3.

Installation
------------

### pip / pip3:
<pre>
pip3 install pydot3
pip install pydot3
</pre>

License
=======

This code is distributed under the MIT license.

Prerequisites:
--------------

- pyparsing
- GraphViz
